---
title: <span class="badge object-type-scalar"></span> Kilobytes
---
# <span class="badge object-type-scalar"></span> Kilobytes

Data: kilobytes

## Definition

```python
# Data: kilobytes
Kilobytes: typing.Literal["deckbytes"] = "deckbytes"
```
